==> openshift-model-monitoring-6.7.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackConfirmationFieldBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SlackConfirmationFieldBuilder extends SlackConfirmationFieldFluentImpl<SlackConfirmationFieldBuilder> implements VisitableBuilder<SlackConfirmationField,SlackConfirmationFieldBuilder>{
  public SlackConfirmationFieldBuilder() {
    this(false);
  }
  public SlackConfirmationFieldBuilder(Boolean validationEnabled) {
    this(new SlackConfirmationField(), validationEnabled);
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationFieldFluent<?> fluent) {
    this(fluent, false);
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationFieldFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SlackConfirmationField(), validationEnabled);
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationFieldFluent<?> fluent,SlackConfirmationField instance) {
    this(fluent, instance, false);
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationFieldFluent<?> fluent,SlackConfirmationField instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withDismissText(instance.getDismissText());
      fluent.withOkText(instance.getOkText());
      fluent.withText(instance.getText());
      fluent.withTitle(instance.getTitle());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationField instance) {
    this(instance,false);
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationField instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withDismissText(instance.getDismissText());
      this.withOkText(instance.getOkText());
      this.withText(instance.getText());
      this.withTitle(instance.getTitle());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  SlackConfirmationFieldFluent<?> fluent;
  Boolean validationEnabled;
  public SlackConfirmationField build() {
    SlackConfirmationField buildable = new SlackConfirmationField(fluent.getDismissText(),fluent.getOkText(),fluent.getText(),fluent.getTitle());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-monitoring-6.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackConfirmationFieldBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SlackConfirmationFieldBuilder extends SlackConfirmationFieldFluent<SlackConfirmationFieldBuilder> implements VisitableBuilder<SlackConfirmationField,SlackConfirmationFieldBuilder>{
  public SlackConfirmationFieldBuilder() {
    this(false);
  }
  public SlackConfirmationFieldBuilder(Boolean validationEnabled) {
    this(new SlackConfirmationField(), validationEnabled);
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationFieldFluent<?> fluent) {
    this(fluent, false);
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationFieldFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SlackConfirmationField(), validationEnabled);
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationFieldFluent<?> fluent,SlackConfirmationField instance) {
    this(fluent, instance, false);
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationFieldFluent<?> fluent,SlackConfirmationField instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new SlackConfirmationField());

    if (instance != null) {
      fluent.withDismissText(instance.getDismissText());
      fluent.withOkText(instance.getOkText());
      fluent.withText(instance.getText());
      fluent.withTitle(instance.getTitle());
      fluent.withDismissText(instance.getDismissText());
      fluent.withOkText(instance.getOkText());
      fluent.withText(instance.getText());
      fluent.withTitle(instance.getTitle());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationField instance) {
    this(instance,false);
  }
  public SlackConfirmationFieldBuilder(SlackConfirmationField instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new SlackConfirmationField());

    if (instance != null) {
      this.withDismissText(instance.getDismissText());
      this.withOkText(instance.getOkText());
      this.withText(instance.getText());
      this.withTitle(instance.getTitle());
      this.withDismissText(instance.getDismissText());
      this.withOkText(instance.getOkText());
      this.withText(instance.getText());
      this.withTitle(instance.getTitle());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  SlackConfirmationFieldFluent<?> fluent;
  Boolean validationEnabled;
  public SlackConfirmationField build() {
    SlackConfirmationField buildable = new SlackConfirmationField(fluent.getDismissText(),fluent.getOkText(),fluent.getText(),fluent.getTitle());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
